@@ -29,6 +29,12 @@
 class TBuffer;
 #endif
 
+#ifdef HEPMC3_PROTOBUFIO
+namespace HepMC3_pb {
+class GenEventData;
+}
+#endif
+
 
 namespace HepMC3 {
 
@@ -59,7 +65,7 @@ public:
     /// @brief Destructor
     ~GenEvent();
 
-    /// @brief Assignment operator
+    /// @brief Copy Assignment operator
     GenEvent& operator=(const GenEvent&);
 
     /// @name Particle and vertex access
@@ -80,13 +86,14 @@ public:
 
     /// @name Particle and vertex access
     /// @{
-    /// Particles size, HepMC2 compatibility
+
+    /// @brief Particles size, HepMC2 compatibility
     inline int particles_size() const { return m_particles.size(); }
-    /// Particles empty, HepMC2 compatibility
+    /// @brief Particles empty, HepMC2 compatibility
     inline bool particles_empty() const { return m_particles.empty(); }
-    /// Vertices size, HepMC2 compatibility
+    /// @brief Vertices size, HepMC2 compatibility
     inline int vertices_size() const { return m_vertices.size(); }
-    /// Vertices empty, HepMC2 compatibility
+    /// @brief Vertices empty, HepMC2 compatibility
     inline bool vertices_empty() const { return m_vertices.empty(); }
     /// @}
 
@@ -206,9 +213,11 @@ public:
         shift_position_by(delta);
     }
 
-    /// @brief Boost event using x,y,z components of @a delta as velocities
+    /// @brief Boost event using x,y,z components of @a delta as velocity fractions
     bool boost( const FourVector&  delta );
     /// @brief Rotate event using x,y,z components of @a delta as rotation angles
+    ///
+    /// @todo Clarify orders of rotations?
     bool rotate( const FourVector&  delta );
     /// @brief Change sign of @a axis
     bool reflect(const int axis);
@@ -318,17 +327,6 @@ public:
     /// @name Deprecated functionality
     /// @{
 
-    /// @brief Add particle by raw pointer
-    ///
-    /// @deprecated Use GenEvent::add_particle( const GenParticlePtr& ) instead
-    void add_particle( GenParticle *p );
-
-    /// @brief Add vertex by raw pointer
-    ///
-    /// @deprecated Use GenEvent::add_vertex( const GenVertexPtr& ) instead
-    void add_vertex  ( GenVertex *v );
-
-
     /// @brief Set incoming beam particles
     /// @deprecated Backward compatibility
     void set_beam_particles(GenParticlePtr p1, GenParticlePtr p2);
@@ -356,9 +354,14 @@ public:
 #ifdef HEPMC3_ROOTIO
     /// @brief ROOT I/O streamer
     void Streamer(TBuffer &b);
-    /// @}
 #endif
 
+#ifdef HEPMC3_PROTOBUFIO
+    /// @brief protobuf I/O reader
+    void read_data(HepMC3_pb::GenEventData const &data);
+#endif
+    /// @}
+
 private:
 
     /// @name Fields
